//baseline parametrization

% Calibrated parameters 
% preferences 
parameters BET HABIT RISK VARPHI SIGMA;
% adjustment costs 
parameters GAMMA_F GAMMA_L GAMMA_Y GAMMA_P;
% depreciation rates
parameters DELTA_F DELTA_L DELTA_Y;
% technology 
parameters EPSILON_E EPSILON_Y VAROMEGA_VAY VAROMEGA_E VAROMEGA_EF VAROMEGA_EL ALPHA_Y EPSILON_F VAROMEGA_VAF VAROMEGA_X;
% policy paramteres - Taylor rule and price indexation and cost of intermediation 
parameters KAPPA_RN KAPPA_Y KAPPA_PI KAPPA_P TAU_CP;
% banking sector
parameters OMEGA THETA RHO; 
% Implied parameters 
parameters CHI PSI_F PSI_L;

% Shock parameters 
% autocor
parameters RHO_AF RHO_AL RHO_AY RHO_XIF RHO_XIL RHO_XIY RHO_X RHO_TAUX; 
% sigmas
parameters
SIGMA_AF SIGMA_AL SIGMA_AY SIGMA_XIF SIGMA_XIL SIGMA_XIY SIGMA_X SIGMA_TAUX;


%Steady state values of all the variables
parameters 
B_SS % total deposits
B_P_SS % private deposits/bank deposits
B_G_SS % public bonds issued to finance credit policy
C_SS % consumption
C_G_SS % public consumption 
E_SS % energy aggregate
E_F_SS % fossil energy
E_L_SS % low-carbon energy
I_F_SS % investment fossil sector
I_L_SS % investment low-carbon sector
I_Y_SS % investment production sector 
lambda_SS % Lagrange multiplier
LAMBDA_SS % households' stochastic discount factor
MC_SS % marginal costs production sector
N_SS % labor 
NU_SS % marginal value of net worth
NW_SS % net worth
NW_E_SS % net worth existing bankers
NW_NEW_SS % net worth new bankers
K_F_SS % total capital fossil sector 
K_L_SS % capital low-carbon sector
K_Y_SS % capital production sector
P_E_SS % real aggregate energy price
P_EF_SS % real fossil energy price
P_EL_SS % real low-carbon energy price
PHI_SS % leverage ratio
PI_SS % inflation
Q_F_SS % price of capital fossil sector
Q_L_SS % price of capital low-carbon sector
Q_Y_SS % price of capital production sector
R_SS % real interest rate
R_F_SS % stochastic return on fossil sector's assets
R_L_SS % stochastic returns on low-carbon sector's assets
R_Y_SS % stochastic return on production sector's assets
RN_SS % nominal interest rate N.B. in the tex file RN=(1+i) 
S_F_SS % total intermediated assets fossil sector
S_L_SS % total intermediated assets low-carbon sector
S_Y_SS % total intermediated assets production sector
S_FP_SS % privately intermediated assets fossil sector
S_LP_SS % privately intermediated low-carbon sector
S_YP_SS % privately intermediated assets production sector
S_FG_SS % assets fossil sector intermediated via government assistance
S_LG_SS % assets low-carbon sector intermediated via government assistance
S_YG_SS % assets production sector intermediated via government assistance
T_SS % lump-sum taxes
U_SS % utility
V_SS % loss supported by bankers/value function
VA_Y_SS % value added production sector
VA_F_SS % value added fossil sector
W_SS % real wage production sector
X_SS % polluting input
Y_SS; % production 
%price of X 
parameters P_X_SS; % carbon price 

% Credit policy variables 
parameters CREDIT_L_SS % credit policy low-carbon sector
CREDIT_F_SS % credit policy fossil sector
CREDIT_Y_SS; % credit policy production sector

%tax rates 
parameters 
TAU_X_SS; % carbon tax

%exogenous process and additional variables 
parameters A_F_SS % technology fossil sector
A_L_SS % technology low-carbon sector
A_Y_SS % technology
LEV_SS %leverage ration (non-risk adjusted)
SPREAD_Y_SS % spread= return on Y - safe rate
SPREAD_F_SS % spread= return on F - safe rate
SPREAD_L_SS % spread= return on L - safe rate
G_SS % total public expenditure
XI_F_SS % quality of capital fossil sector
XI_L_SS % quality of capital low-carbon sector
XI_Y_SS; % quality of capital production sector

%total public credit
S_FG_SS=0; % assets fossil sector intermediated via government assistance
S_LG_SS=0; % assets low-carbon sector intermediated via government assistance
S_YG_SS=0; % assets final good sector intermediated via government assistance
B_G_SS=S_FG_SS+S_LG_SS+S_YG_SS; % public bonds issued to finance credit policy
%credit policy coefficients
CREDIT_L_SS=0;
CREDIT_F_SS=0;
CREDIT_Y_SS=0;
% tax rates
TAU_X_SS=0; %carbon tax %0

% target inflation
PI_SS=(1+1.9/100)^0.25;

% variables that collapse to one in steady state
% The Qs
Q_F_SS=1; % price of capital fossil sector
Q_L_SS=1; % price of capital low-carbon sector
Q_Y_SS=1; % price of capital production sector
%quality of capital
XI_F_SS=1; % capital quality process fossil sector
XI_L_SS=1; % capital quality process low-carbon sector
XI_Y_SS=1; % capital quality process production sector
% stochastic discount
LAMBDA_SS=1; % households' stochastic discount factor

% policy parameters
TAU_CP=0.00001; %credit policy cost
% Monetary parameters and idexation to past inflation
KAPPA_RN=0.6571; %0.743 % smoothing parameter of the Taylor rule
KAPPA_P=0.6018; % price backward indexation
KAPPA_Y=0.0684; % output gap coefficient of the Taylor rule
KAPPA_PI=2.9985; % inflation coefficient of the Taylor rule

%real interest rate
R_SS=1.00466815332819;


% Preferences parameters
SIGMA=6; % elasticity of substitution between final goods varieties
HABIT=0.6324; % habit parameter 0.62
RISK=1.5365; % risk aversion coefficient
VARPHI=0.7223; % inverse of the Frisch elasticity of labor supply production sector

%Some implied variables
BET=1/R_SS; % discount rate
RN_SS=PI_SS/BET; % nominal interest factor
MC_SS=(SIGMA-1)/SIGMA; % marginal costs production sector

%depreciation rate see Baldwin et al. 2020 - JEEM
DELTA_Y=0.025;
DELTA_F=0.015;
DELTA_L=0.002;

%Adjustment cost parameters 10.78
GAMMA_F=13.3921;
GAMMA_L=14.5498;
GAMMA_Y=9.4913;
GAMMA_P=54.5121;

%Normalizations and consumption
Y_SS=1; %production
N_SS=0.1843;% labor production sector
C_SS=0.560183207168559;

% Spreads and risky rates
R_Y_SS=1.007858206077421;
SPREAD_Y_SS=R_Y_SS-R_SS;
%Spreads US data
% Spreads and risky rates: keep the same relative size
%SPREAD_Y_SS=0.006641842;
%R_Y_SS=R_SS+SPREAD_Y_SS;
%SPREAD_F_SS=0.007185803;
%R_F_SS=R_SS+SPREAD_F_SS;
%SPREAD_L_SS=0.008239136;%0.0002;
%R_L_SS=R_SS+SPREAD_L_SS;
SPREAD_F_SS=0.007185803*SPREAD_Y_SS/0.006641842;
SPREAD_L_SS=0.008239136*SPREAD_Y_SS/0.006641842;
R_F_SS=R_SS+SPREAD_F_SS;
R_L_SS=R_SS+SPREAD_L_SS;
%financial sector I block: PSIs
PSI_L=SPREAD_L_SS/SPREAD_Y_SS; % additional abscording rate of low-carbon sector assets 
PSI_F=PSI_L*SPREAD_F_SS/SPREAD_L_SS; % additional abscording rate of fossil sector assets 

%production sector Y
EPSILON_Y=0.5; % elasticity of substitution between value added in the production sector and energy
ALPHA_Y=0.36; % capital share production sector
VAROMEGA_E=0.1;%
VAROMEGA_VAY=1-VAROMEGA_E; % factor share of value added in the production sector
EPSILON_Y_FAC=(EPSILON_Y-1)/EPSILON_Y;
INV_EPSILON_Y_FAC=EPSILON_Y/(EPSILON_Y-1);
INV_EPSILON_Y=1/EPSILON_Y;
E_SS=0.165;%0.0527; % energy aggregate
VA_Y_SS=((Y_SS^(EPSILON_Y_FAC)-(VAROMEGA_E^(INV_EPSILON_Y))*E_SS^(EPSILON_Y_FAC))/(VAROMEGA_VAY^(INV_EPSILON_Y)))^(INV_EPSILON_Y_FAC); % value added production sector
K_Y_SS=(MC_SS*(Y_SS^(INV_EPSILON_Y))*(VAROMEGA_VAY^(INV_EPSILON_Y))*(VA_Y_SS^(EPSILON_Y_FAC))*(ALPHA_Y))/(XI_Y_SS*(R_Y_SS*Q_Y_SS/XI_Y_SS-Q_Y_SS+DELTA_Y));
A_Y_SS=VA_Y_SS/(((XI_Y_SS*K_Y_SS)^ALPHA_Y)*(N_SS^(1-ALPHA_Y)));
W_SS=MC_SS*(Y_SS^(1/EPSILON_Y))*(VAROMEGA_VAY^(1/EPSILON_Y))*(VA_Y_SS^(EPSILON_Y_FAC))*(1-ALPHA_Y)/N_SS; % real wage production sector
%energy sector
P_E_SS=((MC_SS^EPSILON_Y)*VAROMEGA_E*Y_SS/E_SS)^(INV_EPSILON_Y); % real aggregate energy price

%energy sector
EPSILON_E=5;%2; % elasticity of substitution between low-carbon and fossil energy
VAROMEGA_EL=0.2; % factor share of low-carbon energy in the production sector
VAROMEGA_EF=1-VAROMEGA_EL; % factor share of fossil energy in the production sector 
P_EF_SS=P_E_SS; % real fossil energy price
P_EL_SS=P_E_SS; % real low-carbon energy price
E_F_SS=VAROMEGA_EF*(P_EF_SS/P_E_SS)^(-EPSILON_E)*E_SS; % fossil energy
E_L_SS=VAROMEGA_EL*(P_EL_SS/P_E_SS)^(-EPSILON_E)*E_SS; % low-carbon energy
%low carbon energy
K_L_SS=P_EL_SS*E_L_SS/(XI_L_SS*(R_L_SS*Q_L_SS/XI_L_SS-Q_L_SS+DELTA_L));
A_L_SS=E_L_SS/(XI_L_SS*K_L_SS); % technology low-carbon sector

%fossil energy
X_SS=0.033; %this is calibrated so as to generate a vlue for I_F_SS so that I_SS is about 0.2 and to match Px*X
EPSILON_F=0.3; % elasticity of substitution between value added in the fossil sector and fossil resource
VAROMEGA_VAF=0.7; % factor share of value added in the fossil energy sector
VAROMEGA_X=1-VAROMEGA_VAF; % factor share of natural resource in the fossil energy sector
EPSILON_F_FAC=(EPSILON_F-1)/EPSILON_F;
INV_EPSILON_F_FAC=EPSILON_F/(EPSILON_F-1);
INV_EPSILON_F=1/EPSILON_F;
VA_F_SS=((E_F_SS^(EPSILON_F_FAC)-(VAROMEGA_X^(INV_EPSILON_F))*X_SS^(EPSILON_F_FAC))/(VAROMEGA_VAF^(INV_EPSILON_F)))^(INV_EPSILON_F_FAC);
K_F_SS=(P_EF_SS*(E_F_SS^INV_EPSILON_F)*(VAROMEGA_VAF^INV_EPSILON_F)*(VA_F_SS^EPSILON_F_FAC))/(XI_F_SS*(R_F_SS*Q_F_SS/XI_F_SS-Q_F_SS+DELTA_F)); % stochastic return on fossil sector's assets
A_F_SS=VA_F_SS/(XI_F_SS*K_F_SS);
P_X_SS=P_EF_SS*(E_F_SS^INV_EPSILON_F)*(VAROMEGA_X^INV_EPSILON_F)*(X_SS^(-INV_EPSILON_F));

%investments
I_F_SS=K_F_SS*DELTA_F;
I_L_SS=K_L_SS*DELTA_L;
I_Y_SS=K_Y_SS*DELTA_Y;

%public spending
G_SS=Y_SS-C_SS-I_F_SS-I_L_SS-I_Y_SS;
C_G_SS=G_SS-TAU_CP*(S_FG_SS+S_LG_SS+S_YG_SS); % total public expenditure


%FINANCIAL SECTOR
THETA=0.95535; %0.899430; %0.89950.8995 (0.09) %0.9055 (0.1);%8206; % survival rate of the bankers set so that NW_NEW_SS>0 (given the positive spreads this wouldn't be the case for very high theta)
%total assets
S_F_SS=K_F_SS; % total intermediated assets fossil sector
S_L_SS=K_L_SS; % total intermediated assets low-carbon sector
S_Y_SS=K_Y_SS; % total intermediated assets production sector
%total private credit
S_FP_SS=S_F_SS-S_FG_SS; % privately intermediated assets fossil sector
S_LP_SS=S_L_SS-S_LG_SS; % privately intermediated low-carbon sector
S_YP_SS=S_Y_SS-S_YG_SS; % privately intermediated assets production sector
% banks' net worth
NW_SS=0.08*(S_YP_SS+PSI_L*S_LP_SS+PSI_F*S_FP_SS); %0.09
B_P_SS=S_FP_SS+S_LP_SS+S_YP_SS- NW_SS; % private deposits/bank deposits
PHI_SS=(S_YP_SS+PSI_L*S_LP_SS+PSI_F*S_FP_SS)/NW_SS; % risk-adjusted leverage ratio
NW_E_SS=THETA*(SPREAD_Y_SS*S_YP_SS/NW_SS+SPREAD_L_SS*S_LP_SS/NW_SS+SPREAD_F_SS*S_FP_SS/NW_SS+R_SS)*NW_SS; % net worth existing bankers 
NW_NEW_SS=NW_SS-NW_E_SS; % net worth new bankers
OMEGA=NW_NEW_SS/(S_FP_SS+S_LP_SS+S_YP_SS);
NU_SS=(PHI_SS*BET*(1-THETA)*SPREAD_Y_SS+BET*(1-THETA)*R_SS)/(1-BET*THETA*R_SS-PHI_SS*BET*THETA*SPREAD_Y_SS); % marginal value of an increase in assets
RHO=NU_SS/PHI_SS;
V_SS=RHO*(S_YP_SS+PSI_L*S_LP_SS+PSI_F*S_FP_SS); %or V_SS=NU_SS*NW_SS; % loss supported by bankers/value function
LEV_SS=(S_YP_SS+S_LP_SS+S_FP_SS)/NW_SS; %effective leverage

%PUBLIC SECTOR
T_SS=-(TAU_X_SS*P_X_SS*X_SS)+G_SS;
B_SS=B_G_SS+B_P_SS; %total deposits
%Other implied 
lambda_SS=(C_SS-HABIT*C_SS)^(-RISK)-BET*HABIT*((C_SS-HABIT*C_SS)^(-RISK)); %with internal habit
%implied values preferences parameters and utility
CHI= lambda_SS*W_SS/(N_SS^VARPHI); % disutility of labor
U_SS=(1/(1-BET))*((((C_SS-HABIT*C_SS)^(1-RISK)-1)/(1-RISK))-CHI*(N_SS^(1+VARPHI))/(1+VARPHI));

%U_SS=(1/(1-BET))*((log(C_SS-HABIT*C_SS))-CHI*(N_SS^(1+VARPHI))/(1+VARPHI));

%shocks' block
RHO_AF=0.8; 
RHO_AL=0.8; 
RHO_AY=0.95; 
RHO_XIF=0.7965; 
RHO_XIL=0.8203; 
RHO_XIY=0.9197; 
RHO_X=0.85;
RHO_TAUX=0.9; 


SIGMA_AF=0.0246; 
SIGMA_AL=0.0246; 
SIGMA_AY=0.007;
SIGMA_XIF=0.0041; 
SIGMA_XIL=0.0043; 
SIGMA_XIY=0.032;
SIGMA_X=0.001;
SIGMA_TAUX=0.001;






